@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -106,6 +106,12 @@ ASObject::ASObject(QVariantMap objectMap,
                                    .value("height").toInt();
         }        
 
+        // And if there's no small image for some reason, use the full one as thumbnail
+        if (smallImageUrl.isEmpty())
+        {
+            smallImageUrl = imageUrl;
+        }
+
         qDebug() << "postImage:" << imageUrl << "> Small:" << smallImageUrl;
 
         // To have a filename with extension, even when downloading from proxyURL's
