@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -162,7 +162,7 @@ Composer::Composer(GlobalObject *globalObject, bool forPublisher,
     nickCompleter->setMaxVisibleItems(15);
     nickCompleter->setCompletionColumn(0);
     nickCompleter->setCaseSensitivity(Qt::CaseInsensitive);
-    nickCompleter->setModelSorting(QCompleter::CaseSensitivelySortedModel); // TMP; FIXME
+    nickCompleter->setModelSorting(QCompleter::CaseInsensitivelySortedModel);
     connect(nickCompleter, SIGNAL(activated(QModelIndex)),
             this, SLOT(insertCompletedNick(QModelIndex)));
 
