@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <QStringList>
 #include <QSize>
 #include <QStandardItemModel>
+#include <QSortFilterProxyModel>
 
 #include <QDebug>
 
@@ -134,7 +135,7 @@ public:
                   QString title,
                   QString contents);
 
-    QStandardItemModel *getNickCompletionModel();
+    QSortFilterProxyModel *getNickCompletionModel();
     void addToNickCompletionModel(QString id, QString name, QString url);
     void removeFromNickCompletionModel(QString id);
     void clearNickCompletionModel();
@@ -237,6 +238,7 @@ private:
 
     // Other stuff
     QStandardItemModel *nickCompletionModel;
+    QSortFilterProxyModel *filterCompletionModel;
     int timelineHeight;
 
     bool programClosing;
