@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -41,19 +41,22 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     this->suggestedFilename = suggestedFN;
     this->imageIsAnimated = isAnimated;
 
-    zoomLevel = 1.0;
+    zoomLevel = 1.000;
+    rotationAngle = 0.000;
     fitToWindow = true;
 
+    loadingLabel = new QLabel(this);
+    loadingLabel->setAlignment(Qt::AlignCenter);
 
-    imageLabel = new QLabel(this);
-    imageLabel->setAlignment(Qt::AlignCenter);
+    graphicsPixmapItem = new QGraphicsPixmapItem(nullptr); // FIXME: ensure deletion
+    graphicsScene = new QGraphicsScene(this);
 
-    scrollArea = new QScrollArea(this);
-    scrollArea->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
-    scrollArea->setWidget(imageLabel);
-    scrollArea->setWidgetResizable(true);
-    scrollArea->setAlignment(Qt::AlignCenter);
+    // This label needs to NOT have a parent, to work properly inside the QGraphicsScene
+    movieLabel = new QLabel(); // Will be deleted in destructor
+    movieLabel->setCursor(Qt::OpenHandCursor); // To match the static GraphicsPixmapItem
 
+    ivGraphicsView = new IvGraphicsView(graphicsScene, this);
+    ivGraphicsView->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
 
 
     // Buttons
@@ -102,6 +105,8 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     zoomInButton->setDisabled(true);
     connect(zoomInButton, SIGNAL(clicked()),
             this, SLOT(zoomIn()));
+    connect(ivGraphicsView, SIGNAL(zoomInRequested()),
+            zoomInButton, SLOT(click()));
 
 
     zoomOutButton = new QPushButton(QIcon::fromTheme("zoom-out"),
@@ -111,6 +116,8 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     zoomOutButton->setDisabled(true);
     connect(zoomOutButton, SIGNAL(clicked()),
             this, SLOT(zoomOut()));
+    connect(ivGraphicsView, SIGNAL(zoomOutRequested()),
+            zoomOutButton, SLOT(click()));
 
 
     rotateLeftButton = new QPushButton(QIcon::fromTheme("object-rotate-left",
@@ -169,7 +176,8 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
     buttonsLayout->addWidget(closeButton);
 
     mainLayout = new QVBoxLayout();
-    mainLayout->addWidget(scrollArea);
+    mainLayout->addWidget(loadingLabel);
+    mainLayout->addWidget(ivGraphicsView);
     mainLayout->addLayout(buttonsLayout);
     this->setLayout(mainLayout);
 
@@ -215,6 +223,8 @@ ImageViewer::ImageViewer(QString url, QSize imageSize,
 
 ImageViewer::~ImageViewer()
 {
+    delete movieLabel; // Since it needed to have no parent
+    delete this->graphicsPixmapItem; // Needed? FIXME
     qDebug() << "ImageViewer destroyed";
 }
 
@@ -285,20 +295,27 @@ void ImageViewer::loadImage(QString url, QSize expectedSize)
     this->originalFileURI = MiscHelpers::getCachedImageFilename(url);
 
     originalPixmap = QPixmap(originalFileURI);
+
     if (originalPixmap.isNull())
     {
+        this->ivGraphicsView->hide();
+
         QString expectedResolution = MiscHelpers::resolutionString(expectedSize.width(),
                                                                    expectedSize.height());
 
-        this->imageLabel->setText("<img src=\":/images/image-loading.png\" />"
-                                  "<br /><br /><br />"
-                                  "<big>" + tr("Downloading full image...")
-                                  + "</big>"
-                                    "<br /><br />"
-                                    "(" + expectedResolution + ")");
+        this->loadingLabel->setText("<img src=\":/images/image-loading.png\" />"
+                                    "<br /><br /><br />"
+                                    "<big>" + tr("Downloading full image...")
+                                    + "</big>"
+                                      "<br /><br />"
+                                      "(" + expectedResolution + ")");
     }
     else
     {
+        this->loadingLabel->clear();
+        this->loadingLabel->hide();
+        this->ivGraphicsView->show();
+
         QString resolution = MiscHelpers::resolutionString(originalPixmap.width(),
                                                            originalPixmap.height());
 
@@ -312,10 +329,16 @@ void ImageViewer::loadImage(QString url, QSize expectedSize)
             movie->setFileName(this->originalFileURI);
             movie->start();
 
-            imageLabel->setMovie(movie);
+            movieLabel->setMovie(movie);
+            labelProxyWidget = graphicsScene->addWidget(movieLabel);
 
             restartButton->setEnabled(true);
         }
+        else
+        {
+            graphicsPixmapItem->setPixmap(originalPixmap);
+            graphicsScene->addItem(graphicsPixmapItem);
+        }
 
 
         this->drawImage();
@@ -337,35 +360,17 @@ void ImageViewer::drawImage()
 {
     toggleZoomButtons();
 
-    int width;
-    int height;
+    ivGraphicsView->resetTransform(); // Reset and re-scaled+re-rotated every time
+    ivGraphicsView->rotate(this->rotationAngle);
 
     if (fitToWindow)
     {
-        width = qMin(scrollArea->width() - 8,   // 8px as margin
-                     originalPixmap.width());
-        height = qMin(scrollArea->height() - 8,
-                      originalPixmap.height());
+        ivGraphicsView->fitInView(graphicsPixmapItem, Qt::KeepAspectRatio);
     }
     else
     {
-        width = originalPixmap.width() * zoomLevel;
-        height = originalPixmap.height() * zoomLevel;
-    }
-
-
-    if (!this->imageIsAnimated)
-    {
-        imageLabel->setPixmap(originalPixmap.scaled(width, height,
-                                                    Qt::KeepAspectRatio,
-                                                    Qt::SmoothTransformation));
-    }
-    else
-    {
-        QSize movieSize(originalPixmap.width(),
-                        originalPixmap.height());
-        movieSize.scale(width, height, Qt::KeepAspectRatio);
-        movie->setScaledSize(movieSize);
+        ivGraphicsView->scale(zoomLevel, zoomLevel);
+        fullButton->setText(QString("%1%").arg(zoomLevel * 100));
     }
 
     this->updateButtons();
@@ -374,8 +379,8 @@ void ImageViewer::drawImage()
 
 void ImageViewer::toggleZoomButtons()
 {
-    this->zoomInButton->setDisabled(this->zoomLevel == 5.0);
-    this->zoomOutButton->setDisabled(this->zoomLevel < 0.1);
+    this->zoomInButton->setDisabled(this->zoomLevel >= 4.0);
+    this->zoomOutButton->setDisabled(this->zoomLevel <= 0.1);
 }
 
 
@@ -389,7 +394,9 @@ void ImageViewer::updateButtons()
         fullButton->setShortcut(QKeySequence(Qt::Key_F));
 
         this->zoomInButton->setVisible(false);
+        this->zoomInButton->setEnabled(false);
         this->zoomOutButton->setVisible(false);
+        this->zoomOutButton->setEnabled(false);
     }
     else
     {
@@ -400,6 +407,7 @@ void ImageViewer::updateButtons()
 
         this->zoomInButton->setVisible(true);
         this->zoomOutButton->setVisible(true);
+        this->toggleZoomButtons();
     }
 }
 
@@ -423,12 +431,12 @@ void ImageViewer::onImageFailed(QString url)
 {
     if (url == this->imageUrl)
     {
-        this->imageLabel->setText("<img src=\":/images/image-missing.png\" />"
-                                  "<br /><br /><br />"
-                                  "<big>" + tr("Error downloading image!")
-                                  + "<br /><br />"
-                                  + tr("Try again later.")
-                                  + "</big>");
+        this->loadingLabel->setText("<img src=\":/images/image-missing.png\" />"
+                                    "<br /><br /><br />"
+                                    "<big>" + tr("Error downloading image!")
+                                    + "<br /><br />"
+                                    + tr("Try again later.")
+                                    + "</big>");
     }
 }
 
@@ -474,7 +482,9 @@ void ImageViewer::restartAnimation()
 void ImageViewer::zoomToFit()
 {
     this->fitToWindow = !fitToWindow;
-    this->zoomLevel = 1.0; // Reset
+    this->zoomLevel = 1.000; // Reset
+
+    this->fullButton->setText("100%");
 
     this->drawImage();
 }
@@ -484,20 +494,16 @@ void ImageViewer::zoomIn()
 {
     this->fitToWindow = false;
 
-    if (zoomLevel > 1)
+    if (zoomLevel < 4.0)
     {
-        this->zoomLevel += 0.5;
-        if (zoomLevel > 5)
+        zoomLevel += 0.1;
+        if (zoomLevel > 4.0)
         {
-            zoomLevel = 5.0;
+            zoomLevel = 4.000;
         }
-    }
-    else
-    {
-        this->zoomLevel += 0.1;
-    }
 
-    this->drawImage();
+        this->drawImage();
+    }
 }
 
 
@@ -506,42 +512,32 @@ void ImageViewer::zoomOut()
 {
     this->fitToWindow = false;
 
-    if (zoomLevel > 1)
+    if (zoomLevel > 0.10)
     {
-        this->zoomLevel -= 0.5;
-    }
-    else
-    {
-        this->zoomLevel -= 0.1;
+        zoomLevel -= 0.1;
         if (zoomLevel < 0.1)
         {
-            zoomLevel = 0.05;
+            zoomLevel = 0.100;
         }
-    }
 
-    this->drawImage();
+        this->drawImage();
+    }
 }
 
 
 
 void ImageViewer::rotateLeft()
 {
-    QTransform transformation;
-    transformation.rotate(-90.0);
+    this->rotationAngle -= 90.0;
 
-    this->originalPixmap = originalPixmap.transformed(transformation,
-                                                      Qt::SmoothTransformation);
     this->drawImage();
 }
 
 
 void ImageViewer::rotateRight()
 {
-    QTransform transformation;
-    transformation.rotate(90.0);
+    this->rotationAngle += 90.0;
 
-    this->originalPixmap = originalPixmap.transformed(transformation,
-                                                      Qt::SmoothTransformation);
     this->drawImage();
 }
 
@@ -561,6 +557,18 @@ void ImageViewer::closeEvent(QCloseEvent *event)
     this->deleteLater();
 }
 
+void ImageViewer::showEvent(QShowEvent *event)
+{
+    qDebug() << "ImageViewer::showEvent()";
+
+    if (!this->originalPixmap.isNull())
+    {
+        this->drawImage();
+    }
+
+    event->accept();
+}
+
 void ImageViewer::hideEvent(QHideEvent *event)
 {
     qDebug() << "ImageViewer::hideEvent()";
