@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -36,10 +36,14 @@
 #include <QPushButton>
 #include <QMovie>
 #include <QScrollArea>
+#include <QGraphicsPixmapItem>
+#include <QGraphicsProxyWidget>
 
 #include <QDebug>
 
 #include "mischelpers.h"
+#include "ivgraphicsview.h"
+
 
 class ImageViewer : public QWidget
 {
@@ -78,6 +82,7 @@ public slots:
 
 protected:
     virtual void closeEvent(QCloseEvent *event);
+    virtual void showEvent(QShowEvent *event);
     virtual void hideEvent(QHideEvent *event);
     virtual void resizeEvent(QResizeEvent *event);
     virtual void contextMenuEvent(QContextMenuEvent *event);
@@ -85,8 +90,11 @@ protected:
 
 private:
     QVBoxLayout *mainLayout;
-    QLabel *imageLabel;
-    QScrollArea *scrollArea;
+
+    QLabel *loadingLabel;
+    QGraphicsPixmapItem *graphicsPixmapItem;
+    QGraphicsScene *graphicsScene;
+    IvGraphicsView *ivGraphicsView;    
 
     QHBoxLayout *buttonsLayout;
     QPushButton *saveImageButton;
@@ -114,12 +122,17 @@ private:
 
     QPixmap originalPixmap;
     QString originalFileURI;
+
     bool imageIsAnimated;
+    QLabel *movieLabel;
     QMovie *movie;
+    QGraphicsProxyWidget *labelProxyWidget;
+
     QString suggestedFilename;
 
     bool fitToWindow;
-    float zoomLevel;
+    double zoomLevel;
+    double rotationAngle;
 };
 
 #endif // IMAGEVIEWER_H
