@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2016  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -56,6 +56,12 @@ TimeLine::TimeLine(PumpController::requestTypes timelineType,
     QVariantMap demoObjectData;
     demoObjectData.insert("objectType",     "note");
     demoObjectData.insert("id",             "demo-post-id");
+#if 0 // =1 for quick ImageViewer tests
+    demoObjectData.insert("objectType",     "image");
+    QVariantMap demoImageData;
+    demoImageData.insert("url", "http://dianara.nongnu.org/images/mageia.jpg");
+    demoObjectData.insert("fullImage", demoImageData);
+#endif
 
     // Show date/time when latest stable version was released
     demoObjectData.insert("published",      "2016-12-17T21:00:00Z");
@@ -819,7 +825,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
             // The difference in pending posts is in the older pages, so doesn't count
             this->pendingToReceiveNextTime = 0;
 
-            // FIXME 1.3.6: On first load, should display the "pending" number
+            // FIXME 1.4.x: On first load, should display the "pending" number
             // at the bottom or at the "older" button
         }
         else
@@ -1185,7 +1191,7 @@ void TimeLine::addLikesFromMinorFeed(QString objectId, QString objectType,
                                      QString actorId, QString actorName,
                                      QString actorUrl)
 {
-    // FIXME 1.3.6: handle updating likes in comments
+    // FIXME 1.4.x: handle updating likes in comments
     foreach (Post *post, postsInTimeline)
     {
         if (post->getObjectId() == objectId)
@@ -1198,7 +1204,7 @@ void TimeLine::addLikesFromMinorFeed(QString objectId, QString objectType,
 void TimeLine::removeLikesFromMinorFeed(QString objectId, QString objectType,
                                         QString actorId)
 {
-    // FIXME 1.3.6: handle updating likes in comments
+    // FIXME 1.4.x: handle updating likes in comments
     foreach (Post *post, postsInTimeline)
     {
         if (post->getObjectId() == objectId)
